@@ -10,6 +10,7 @@ from ..common import handle_m2m_fields_create_or_update
 from ..depends import QueryItem, get_query, parse_body, get_model
 from ..factory import app
 from ..responses import GetManyOut
+from ..schemas import BulkIn
 from ..shortcuts import get_object_or_404
 
 router = APIRouter()
@@ -49,7 +50,7 @@ async def get_resource(
 async def form(
         resource: str,
 ):
-    resource = await app.get_resource(resource, exclude_pk=True, exclude_m2m_field=False)
+    resource = await app.get_resource(resource, exclude_pk=True, exclude_m2m_field=False, exclude_actions=True)
     return resource.dict(by_alias=True, exclude_unset=True)
 
 
@@ -73,6 +74,17 @@ async def view(
     return resource.dict(by_alias=True, exclude_unset=True)
 
 
+@router.post(
+    '/{resource}/bulk/delete'
+)
+async def bulk_delete(
+        bulk_in: BulkIn,
+        model=Depends(get_model)
+):
+    await model.filter(pk__in=bulk_in.pk_list).delete()
+    return {'success': True}
+
+
 @router.delete(
     '/{resource}/{id}'
 )
@@ -142,4 +154,5 @@ async def get_one(
             relate_model = getattr(obj, m2m_field)  # type:ManyToManyRelation
             ids = await relate_model.all().values_list(relate_model.model._meta.pk_attr)
             ret[m2m_field] = list(map(lambda x: x[0], ids))
+    ret['__str__'] = str(obj)
     return ret
